@@ -283,6 +283,12 @@ static int set_dh_regenerate(prelude_option_t *opt, const char *arg, prelude_str
 }
 
 
+static int set_tls_options(prelude_option_t *opt, const char *arg, prelude_string_t *err, void *context)
+{
+        config.tls_options = strdup(arg);
+        return 0;
+}
+
 
 static char *const2char(const char *val)
 {
@@ -346,7 +352,7 @@ static int set_sched_buffer_size(prelude_option_t *opt, const char *arg, prelude
         unsigned long int value;
 
         value = strtoul(arg, &eptr, 10);
-        if ( value == ULONG_MAX ) {
+        if ( value == ULONG_MAX || eptr == arg ) {
                 prelude_log(PRELUDE_LOG_ERR, "Invalid buffer size specified: '%s'.\n", arg);
                 return -1;
         }
@@ -461,6 +467,7 @@ int manager_options_init(prelude_option_t *rootopt, int *argc, char **argv)
         config.dh_regenerate = 24 * 60 * 60;
         config.connection_timeout = 10;
         config.config_file = PRELUDE_MANAGER_CONF;
+        config.tls_options = NULL;
 
         prelude_option_new_root(&init_first);
 
@@ -506,6 +513,10 @@ int manager_options_init(prelude_option_t *rootopt, int *argc, char **argv)
                            "Number of seconds a client has to successfully authenticate (default 10)",
                            PRELUDE_OPTION_ARGUMENT_REQUIRED, set_connection_timeout, NULL);
 
+        prelude_option_add(rootopt, NULL, PRELUDE_OPTION_TYPE_CFG, 0, "tls-options",
+                           "TLS ciphers, key exchange methods, protocols, macs, and compression options",
+                           PRELUDE_OPTION_ARGUMENT_REQUIRED, set_tls_options, NULL);
+
         prelude_option_add(rootopt, NULL, PRELUDE_OPTION_TYPE_CFG, 0, "dh-parameters-regenerate",
                            "How often to regenerate the Diffie Hellman parameters (in hours)",
                            PRELUDE_OPTION_ARGUMENT_REQUIRED, set_dh_regenerate, NULL);
